==> gulp-auto-angular-1.0.1.tgz: package/main.js <==
var gulp = require("gulp");
var $ = require('gulp-load-plugins')();
var $path = require("path");
var fs = require("fs")
var defaultObj = {
	modulename: "starter",
	css:{
		"./style.less": {
			name: "style.css",
			dest: ["./"]
		}
	},
	js: {
		"./main/main.js":{
			name: "main.js",
			dest: ["./"]
		}
	},
	concat: {
		src:["./main.js","./lib/ionic/js/ionic.bundle.min.js"],
		name: "concat.js",
		dest: ["./"]
	},
	watch: ["style.less","main/**"],
	liverload: false
};
var app = function(config){
	config = mix(defaultObj,config);
	gulp.task("less",function(cb){
		less(config.css,cb);
	})
	gulp.task("browserify",function(cb){
		browserify(config.js,cb);
	});
	// 在合并之前，需要先browserify
	gulp.task("concat",["browserify"],function(cb){
		concat(config.concat,cb);
	});
	gulp.task("watch",function(){
		watch(config)
	})
	gulp.task("livereload",function(){
		$.livereload.listen();
	});
	gulp.task("deploylocal",['concat','less'])
	var arr = ['deploylocal','watch'];
	if(config.liverload) {
		arr.push("livereload");
	};
	gulp.task("default",arr)
};
function less(obj,cb){
	var cssmin = require("gulp-minify-css");
	var sum = 0;
	var flag = 0;
	for(var i in obj) {
		sum++;
		var stream = gulp.src(i)
		.pipe($.plumber({
        	errorHandler: handleError
    	}))
		.pipe($.less())
		.pipe(cssmin())
		.pipe($.rename(obj[i].name))
		.pipe($.livereload())
		.on("end",function(){
			flag++;
			if(cb && flag == sum) {
				cb();
			}
		});
		for(var j in obj[i].dest) {
			stream.pipe(gulp.dest(obj[i].dest[j]));
		}
	}
};
function browserify(obj,cb){
	var sum = 0;
	var flag = 0;
	for(var i in obj) {
		sum++;
		var stream = gulp.src(i)
		.pipe($.plumber({
        	errorHandler: handleError
    	}))
		.pipe($.browserify())
		.pipe($.ngAnnotate())
		.pipe($.rename(obj[i].name))
		.pipe($.livereload())
		.on("end",function(){
			flag++;
			if(cb && flag == sum) {
				cb();
			}
		})
		for(var j in obj[i].dest) {
			stream.pipe(gulp.dest(obj[i].dest[j]));
		}
	}
}
function concat(obj,cb){
	// concat 依赖于browserfy
	var stream = gulp.src(obj.src)
		.pipe($.plumber({
	        errorHandler: handleError
	    }))
	    .pipe($.concat(obj.name))
	    .on("end",function(){
	    	if(cb) {
	    		cb();
	    	}
	    });
    for(var i in obj.dest) {
    	stream.pipe(gulp.dest(obj.dest[i]));
    }
};
function watch(obj){
	for(var i in obj.watch) {
		var watcher = gulp.watch(obj.watch[i],function(e){
			execWatch(e,obj)
		})
		.on("error",function(e){
			console.log(e);
		})
	}
};

function execWatch(e,obj){
	var path = e.path; // 绝对路径
	var ext  = require("path").extname(path);
	switch(ext) {
		case ".html":
			execHtml(e,obj);
			break;
		case ".less":
			execLess(e,obj.css);
			break;
		case ".js":
			execJs(e,ext,obj.js,obj.modulename);
		default:
			execJs(e,ext,obj.js,obj.modulename);
	}
};
function execHtml(event,obj){
	var path = event.path;
	var Path = require("path");
	var basename = Path.basename(path);
	var dir = Path.dirname(path);
	var tplsName = Path.relative(__dirname,dir) + "/";
	gulp.src(path)
		.pipe($.plumber({
            errorHandler: handleError
        }))
		.pipe($.ngHtml2js({
			moduleName: obj.modulename,
    		prefix: tplsName,
    		standalone: true
		}))
		.pipe($.footer("module.exports='<%= name %>';",{name: tplsName + basename}))
		.pipe(gulp.dest(dir))
		.on("end",function(){
			browserify(obj.js);
		})
};
function execLess(e,obj){
	try{
		var basename = require("path").basename(e.path);
		var dirname = require("path").dirname(e.path);
		var parentMainPath = dirname + "/style.less";
		if(e.type == "added") {
			// 新增了
			var stat = fs.statSync(e.path);
			var isFile = stat.isFile();
			if(basename !== "style.less") {	
				gulp.src(parentMainPath)
				.pipe($.header(isFile ? "@import './<%= path %>');\n" :"@import './<%= path %>/style');\n",{path: basename}))
				.pipe(gulp.dest(dirname))
				.on("end",function(){
					// 结束了 开始执行browserify的操作
					if(!isFile) {
						// 不是个文件 是文件夹
						var ws = fs.createWriteStream($path.join(e.path,"./style.less"));
						ws.write("");
						ws.end();
						less(obj,null);
					} else {
						fs.writeFile(e.path,"",{encoding: "utf8"},function(){
							less(obj,null);
						});
					}
				})
			}
		} else if(e.type == 'deleted') {
			var ext = $path.extname(e.path);
			var basename = $path.basename(e.path,".less");
			var dirname = $path.dirname(e.path);
			var state = fs.statSync(dirname + "/style.less");
			if(state.isFile()) {
				//是个文件  读取文件
				var content_ = fs.readFileSync(dirname + "/style.less").toString();
				var require_reg = new RegExp("require(\'|" + '\"\\.' + $path.sep + ')(' + name + "|" + name + ".less)(\'" + '|\")',"gi");
				content_ = content_.replace(require_reg,"");
			}
		} else {
			browserify(obj,null);
		}
	}catch(e) {
		console.log(e);
	}
	// less(obj);
}
function execJs(e,ext,obj,modulename) {
	/**
	 * [basename description]
	 * @type {[type]}
	 * 手动的加入到main中
	 */
	try {
		var basename = require("path").basename(e.path);
		var dirname = require("path").dirname(e.path);
		var parentMainPath = dirname + "/main.js";
		if(e.type == "added") {
			// 新增了
			var stat = fs.statSync(e.path);
			var isFile = stat.isFile();
			if(basename !== "main.js") {	
				gulp.src(parentMainPath)
				.pipe($.header(isFile ? "require('./<%= path %>');\n" :"require('./<%= path %>/main');\n",{path: basename}))
				.pipe(gulp.dest(dirname))
				.on("end",function(){
					// 结束了 开始执行browserify的操作
					if(!isFile) {
						// 不是个文件 是文件夹
						var ws = fs.createWriteStream($path.join(e.path,"./main.js"));
						ws.write("angular.module('" + modulename + "')\n");
						ws.end();
						browserify(obj,null);
					} else {
						fs.writeFile(e.path,"angular.module('" + modulename + "')\n",{encoding: "utf8"},function(){
							browserify(obj,null);
						});
					}
				})
			}
		} else if(e.type == 'deleted' && ext) {
			var ext = $path.extname(e.path);
			if(ext) {
				var basename = $path.basename(e.path,".js");
				var dirname = $path.dirname(e.path);
				var state = fs.statSync(dirname + "/main.js");
				if(state.isFile()) {
					//是个文件  读取文件
					var content_ = fs.readFileSync(dirname + "/main.js").toString();
					var require_reg = new RegExp("require\\((\'|" + '\"\\.' + $path.sep + ')(' + name + "|" + name + ".js)(\'" + '|\")' + "\\)","gi");
  					content_ = content_.replace(require_reg,"");
				}
				// 找到期目录下的main
			}
		} else {
			browserify(obj,null);
		}
	} catch(e) {
		console.log(e);
	}
}
function mix(a,b){
	if(typeof b == "object") {
		for(var i in b) {
			if(!a.hasOwnProperty(i)) {
				a[i] = b[i];
			} else {
				// 有
				a[i] = mix(a[i],b[i]);
			}
		}
	} else {
		a = b;
	}
	return a;
};
var handleError = function (err) {
	console.log(err.toString());
	var str = err.toString();
	var reg = /\".+?\"/gi;
	var content = /[^\"]+/gi;
	var name = str.match(reg)[0].match(content)[0];
	var msg = err.message;
	var maindir = $path.dirname(msg.match(reg)[1].match(content)[0]);
	var mainPath = maindir + "/main.js";
	var content_ = fs.readFileSync(mainPath).toString();
	var require_reg = new RegExp("require\\((\'|" + '\")(' + name + "|" + name + ".js)(\'" + '|\")' + "\\)","gi")
  	content_ = content_.replace(require_reg,"");
  	// 将新的内容写入
  	fs.writeFile(mainPath,content_,{
  		encoding: "utf-8"
  	})
  	this.emit('end');
};
module.exports = app;

==> gulp-auto-angular-1.0.3.tgz: package/main.js <==
var gulp = require("gulp");
var $ = require('gulp-load-plugins')();
var $path = require("path");
var fs = require("fs");
var through = require("through2");
var del = require("del");
var defaultObj = {
	modulename: "starter",
	css:{
		"./style.less": {
			name: "style.css",
			dest: ["./"]
		}
	},
	js: {
		"./main/main.js":{
			name: "main.js",
			dest: ["./"]
		}
	},
	concat: {
		src:["./main.js","./lib/ionic/js/ionic.bundle.min.js"],
		name: "concat.js",
		dest: ["./"]
	},
	watch: ["style.less","main/**"],
	liverload: false,
	deploy: {
		dest: ["dist"],
		src: ["style.css","concat.js","index.html"]
	}
};
var app = function(config){
	config = mix(defaultObj,config);
	gulp.task("less",function(cb){
		less(config.css,cb);
	})
	gulp.task("browserify",function(cb){
		browserify(config.js,cb);
	});
	// 在合并之前，需要先browserify
	gulp.task("concat",["browserify"],function(cb){
		concat(config.concat,cb);
	});
	gulp.task("watch",function(){
		watch(config)
	})
	gulp.task("livereload",function(){
		$.livereload.listen();
	});
	gulp.task("deploylocal",['concat','less'])
	var arr = ['deploylocal','watch'];
	if(config.liverload) {
		arr.push("livereload");
	};
	gulp.task("deploy",['concat','less'],function(cb){
		// 迁移
		var sum = 0;
		var flag = 0;
		del("dist");
		for(var i in config.deploy.dest) {
			sum++;
			console.log(config.deploy.src)
			gulp.src(config.deploy.src)
			.pipe(through.obj(function(file,enc,cb){
				var path = $path.relative(process.cwd(),file.path);
				gulp.src(path)
					.pipe(gulp.dest("dist/" + $path.dirname(path)));
				cb();
			}))
			// .pipe(gulp.dest(config.deploy.dest[i]))
			.on("end",function(){
				flag++;
				if(flag == sum) {
					cb();
				}
			});
		}
	})
	gulp.task("default",arr)
};
function less(obj,cb){
	try {
		var cssmin = require("gulp-minify-css");
		var sum = 0;
		var flag = 0;
		for(var i in obj) {
			sum++;
			var stream = gulp.src(i)
			.pipe($.plumber({
	        	errorHandler: handleError
	    	}))
			.pipe($.less())
			.pipe(cssmin())
			.pipe($.rename(obj[i].name))
			.pipe($.livereload())
			.on("end",function(){
				flag++;
				if(cb && flag == sum) {
					cb();
				}
			});
			for(var j in obj[i].dest) {
				stream.pipe(gulp.dest(obj[i].dest[j]));
			}
		}
	} catch(e) {
		console.log(e);
	}
};
function browserify(obj,cb){
	var sum = 0;
	var flag = 0;
	for(var i in obj) {
		sum++;
		var stream = gulp.src(i)
		.pipe($.plumber({
        	errorHandler: handleError
    	}))
		.pipe($.browserify())
		.pipe($.ngAnnotate())
		.pipe($.rename(obj[i].name))
		.pipe($.livereload())
		.on("end",function(){
			flag++;
			if(cb && flag == sum) {
				cb();
			}
		})
		for(var j in obj[i].dest) {
			stream.pipe(gulp.dest(obj[i].dest[j]));
		}
	}
}
function concat(obj,cb){
	// concat 依赖于browserfy
	var stream = gulp.src(obj.src)
		.pipe($.plumber({
	        errorHandler: handleError
	    }))
	    .pipe($.concat(obj.name))
	    .on("end",function(){
	    	if(cb) {
	    		cb();
	    	}
	    });
    for(var i in obj.dest) {
    	stream.pipe(gulp.dest(obj.dest[i]));
    }
};
function watch(obj){
	for(var i in obj.watch) {
		var watcher = gulp.watch(obj.watch[i],function(e){
			execWatch(e,obj)
		})
		.on("error",function(e){
			console.log(e);
		})
	}
};

function execWatch(e,obj){
	var path = e.path; // 绝对路径
	var ext  = require("path").extname(path);
	switch(ext) {
		case ".html":
			execHtml(e,obj);
			break;
		case ".less":
			execLess(e,obj.css);
			break;
		case ".js":
			execJs(e,ext,obj.js,obj.modulename);
		default:
			execJs(e,ext,obj.js,obj.modulename);
			execLess(e,obj.css);
	}
};
function execHtml(event,obj){
	var path = event.path;
	var Path = require("path");
	var basename = Path.basename(path);
	var dir = Path.dirname(path);
	var tplsName = Path.relative(__dirname,dir) + "/";
	gulp.src(path)
		.pipe($.plumber({
            errorHandler: handleError
        }))
		.pipe($.ngHtml2js({
			moduleName: obj.modulename,
    		prefix: tplsName,
    		standalone: true
		}))
		.pipe($.footer("module.exports='<%= name %>';",{name: tplsName + basename}))
		.pipe(gulp.dest(dir))
		.on("end",function(){
			browserify(obj.js);
		})
};
function execLess(e,obj){
	try{
		var basename = require("path").basename(e.path);
		var dirname = require("path").dirname(e.path);
		var parentMainPath = dirname + "/style.less";
		var extname = require("path").extname(e.path);
		if(e.type == "added") {
			// 新增了
			var stat = fs.statSync(e.path);
			var isFile = stat.isFile();
			if(basename !== "style.less" && extname != ".js") {	
				gulp.src(parentMainPath)
				.pipe($.header(isFile ? "@import './<%= path %>';\n" :"@import './<%= path %>/style';\n",{path: basename}))
				.pipe(gulp.dest(dirname))
				.on("end",function(){
					// 结束了 开始执行browserify的操作
					if(!isFile) {
						// 不是个文件 是文件夹
						var ws = fs.createWriteStream($path.join(e.path,"./style.less"));
						ws.write("");
						ws.end();
						less(obj,null);
					} else {
						fs.writeFile(e.path," ",{encoding: "utf8"},function(){
							less(obj,null);
						});
					}
				})
			}
		} else if(e.type == 'deleted') {
			var ext = $path.extname(e.path);
			var basename = $path.basename(e.path,".less");
			var dirname = $path.dirname(e.path);
			var state = fs.statSync(dirname + "/style.less");
			if(state.isFile()) {
				//是个文件  读取文件
				var content_ = fs.readFileSync(dirname + "/style.less").toString();
				console.log(content_);
				var require_reg = new RegExp("@import (\'|" + '\")\\.' + $path.sep + '(' + basename + "|" + basename + ".less)(\'" + '|\");',"gi");
				content_ = content_.replace(require_reg,"");
				fs.writeFile(dirname + "/style.less",content_,{
				  	encoding: "utf-8"
				 })
			}
		} else {
			less(obj,null);
		}
	}catch(e) {
		console.log(e);
	}
	// less(obj);
}
function execJs(e,ext,obj,modulename) {
	/**
	 * [basename description]
	 * @type {[type]}
	 * 手动的加入到main中
	 */
	try {
		var basename = require("path").basename(e.path);
		var dirname = require("path").dirname(e.path);
		var parentMainPath = dirname + "/main.js";
		if(e.type == "added") {
			// 新增了
			var stat = fs.statSync(e.path);
			var isFile = stat.isFile();
			if(basename !== "main.js") {	
				gulp.src(parentMainPath)
				.pipe($.header(isFile ? "require('./<%= path %>');\n" :"require('./<%= path %>/main');\n",{path: basename}))
				.pipe(gulp.dest(dirname))
				.on("end",function(){
					// 结束了 开始执行browserify的操作
					if(!isFile) {
						// 不是个文件 是文件夹
						var ws1 = fs.createWriteStream($path.join(e.path,"./main.js"));
						ws1.write("angular.module('" + modulename + "')\n");
						ws1.end();
						browserify(obj,null);
					} else {
						fs.writeFile(e.path,"angular.module('" + modulename + "')\n",{encoding: "utf8"},function(){
							browserify(obj,null);
						});
					}
				})
			}
		} else if(e.type == 'deleted' && ext) {
			var ext = $path.extname(e.path);
			if(ext) {
				var basename = $path.basename(e.path,".js");
				var dirname = $path.dirname(e.path);
				var state = fs.statSync(dirname + "/main.js");
				if(state.isFile()) {
					//是个文件  读取文件
					var content_ = fs.readFileSync(dirname + "/main.js").toString();
					var require_reg = new RegExp("require\\((\'|" + '\"\\.' + $path.sep + ')(' + basename + "|" + basename + ".js)(\'" + '|\")' + "\\);","gi");
  					content_ = content_.replace(require_reg,"");
  					fs.writeFile(dirname + "/main.js",content_,{
				  		encoding: "utf-8"
				  	})
				}
				// 找到期目录下的main
			}
		} else {
			browserify(obj,null);
		}
	} catch(e) {
		console.log(e);
	}
}
function mix(a,b){
	if(typeof b == "object") {
		for(var i in b) {
			if(!a.hasOwnProperty(i)) {
				a[i] = b[i];
			} else {
				// 有
				a[i] = mix(a[i],b[i]);
			}
		}
	} else {
		a = b;
	}
	return a;
};
var handleError = function (err) {
	var str = err.toString();
	var reg = /\".+?\"/gi;
	var content = /[^\"]+/gi;
	var name = str.match(reg)[0].match(content)[0];
	var msg = err.message;
	var maindir = $path.dirname(msg.match(reg)[1].match(content)[0]);
	var mainPath = maindir + "/main.js";
	var content_ = fs.readFileSync(mainPath).toString();
	var require_reg = new RegExp("require\\((\'|" + '\")(' + name + "|" + name + ".js)(\'" + '|\")' + "\\);","gi")
  	content_ = content_.replace(require_reg,"");
  	// 将新的内容写入
  	fs.writeFile(mainPath,content_,{
  		encoding: "utf-8"
  	})
  	this.emit('end');
};
module.exports = app;
